@@ -1,13 +1,13 @@
 package exact;
 # ABSTRACT: Perl pseudo pragma to enable strict, warnings, features, mro, filehandle methods
 
-use 5.010;
+use 5.014;
 use strict;
 use warnings;
 use namespace::autoclean;
-use TryCatch;
+use Try::Tiny;
 
-our $VERSION = '1.07'; # VERSION
+our $VERSION = '1.08'; # VERSION
 
 use feature    ();
 use utf8       ();
@@ -88,10 +88,10 @@ sub import {
         feature->import(@experiments) unless ( not @experiments or grep { $_ eq 'noexperiments' } @functions );
     }
     catch {
-        my $err = @$;
+        my $err = $_;
         $err =~ s/\s*at .+? line \d+\.\s+//;
         croak("$err via use of exact");
-    }
+    };
 
     warnings->unimport('experimental')
         unless ( $perl_version < 18 or grep { $_ eq 'noskipexperimentalwarnings' } @functions );
@@ -107,7 +107,7 @@ sub import {
 
     eval qq{
         package $caller {
-            use TryCatch;
+            use Try::Tiny;
         };
     } unless ( grep { $_ eq 'notry' } @functions );
 
@@ -161,7 +161,7 @@ exact - Perl pseudo pragma to enable strict, warnings, features, mro, filehandle
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/exact.svg)](https://travis-ci.org/gryphonshafer/exact)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/exact/badge.png)](https://coveralls.io/r/gryphonshafer/exact)
@@ -181,7 +181,7 @@ Instead of this:
     use IO::Handle;
     use namespace::autoclean;
     use Carp qw( croak carp confess cluck );
-    use TryCatch;
+    use Try::Tiny;
 
     no warnings "experimental::signatures";
     no warnings "experimental::refaliasing";
@@ -237,7 +237,7 @@ import L<Carp>'s 4 methods
 
 =item *
 
-import (kinda) L<TryCatch> awesomeness
+import (kinda) L<Try::Tiny>
 
 =back
 
@@ -288,7 +288,7 @@ C<cluck>.
 
 =head2 C<notry>
 
-This skips importing the functionality of L<TryCatch>.
+This skips importing the functionality of L<Try::Tiny>.
 
 =head1 BUNDLES
 
